Learn R Programming

ricegeneann (version 1.0.2)

riceigeneann: Annotation of genes of rice (Oryza Sativa)

Description

ricegeneann Annotation of genes of rice (Oryza Sativa). Input a or some gene name then return a or some information, including the from position, end position, position type and the chromosome number.

Arguments